Introduction — Django Ditto 0.2 documentation

# Introduction

A collection of Django apps for copying things from third-party sites and services. This is still in-progress and things may change. Requires Python 3.4 or 3.5, and Django 1.8 or 1.9.

Currently, Ditto can copy these things from these services:

- Flickr
    - Photos
    - Photosets
    - Original image and video files
    - Users
- Pinboard
    - Bookmarks
- Twitter
    - Tweets
    - Favorites/Likes
    - Images and Animated GIFs (but not videos)
    - Users

It can save these things for one or more account on each service. See possible future services, and overall progress, in this issue.

Public and private Photos, Bookmarks and Tweets are saved, but only public ones are displayed in the included Django views and templates; non-public ones are only visible in the Django admin.

The Ditto app provides:

- Models
- Admin
- Management commands to fetch the data/files
- Views and URLs
- Templates (that use Bootstrap 4)
- Template tags for common things (eg, most recent Tweets, or Flickr photos uploaded on a particular day)